summaryrefslogtreecommitdiffstats
path: root/src/Entities/Player.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Entities/Player.h')
-rw-r--r--src/Entities/Player.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/Entities/Player.h b/src/Entities/Player.h
index 6d092eeb3..fae0e6177 100644
--- a/src/Entities/Player.h
+++ b/src/Entities/Player.h
@@ -459,8 +459,12 @@ public:
*/
Vector3i GetLastBedPos(void) const { return m_LastBedPos; }
- /** Sets the player's bed (home) position */
- void SetBedPos(const Vector3i & a_Pos) { m_LastBedPos = a_Pos; }
+ /** Sets the player's bed (home / respawn) position to the specified position.
+ Sets the respawn world to the player's world. */
+ void SetBedPos(const Vector3i & a_Pos);
+
+ /** Sets the player's bed (home / respawn) position and respawn world to the specified parameters. */
+ void SetBedPos(const Vector3i & a_Pos, cWorld * a_World);
// tolua_end
@@ -584,6 +588,9 @@ protected:
/** The player's last saved bed position */
Vector3i m_LastBedPos;
+ /** The world which the player respawns in upon death */
+ cWorld * m_SpawnWorld;
+
eGameMode m_GameMode;
AString m_IP;